"""added new pipeline type DEFAULT

Revision ID: 1997c3ff664e
Revises: 3d84bc32c8ee
Create Date: 2024-05-30 16:26:20.496957

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '1997c3ff664e'
down_revision: Union[str, None] = '3d84bc32c8ee'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    # op.add_column('pipelines', sa.Column('type', sa.Enum('RAG', 'SUMMARIZER', 'DEFAULT', name='pipelinetypemaster'), nullable=True))
    # ### end Alembic commands ###
    pass

def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('pipelines', 'type')
    # ### end Alembic commands ###
